@@ -21,6 +21,7 @@ supported AWS Services. Instances of these classes should be passed to
 
 Currently supported are:
 
+* Republish a message to another MQTT topic
 * Invoke a Lambda function
 * Put objects to a S3 bucket
 * Put logs to CloudWatch Logs
@@ -30,6 +31,22 @@ Currently supported are:
 * Put records to Kinesis Data Firehose stream
 * Send messages to SQS queues
 
+## Republish a message to another MQTT topic
+
+The code snippet below creates an AWS IoT Rule that republish a message to
+another MQTT topic when it is triggered.
+
+```python
+iot.TopicRule(self, "TopicRule",
+    sql=iot.IotSql.from_string_as_ver20160323("SELECT topic(2) as device_id, timestamp() as timestamp, temperature FROM 'device/+/data'"),
+    actions=[
+        actions.IotRepublishMqttAction("${topic()}/republish",
+            quality_of_service=actions.MqttQualityOfService.AT_LEAST_ONCE
+        )
+    ]
+)
+```
+
 ## Invoke a Lambda function
 
 The code snippet below creates an AWS IoT Rule that invoke a Lambda function
@@ -727,6 +744,131 @@ class FirehoseRecordSeparator(enum.Enum):
     '''
 
 
+@jsii.implements(aws_cdk.aws_iot.IAction)
+class IotRepublishMqttAction(
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-cdk/aws-iot-actions.IotRepublishMqttAction",
+):
+    '''(experimental) The action to put the record from an MQTT message to republish another MQTT topic.
+
+    :stability: experimental
+    :exampleMetadata: infused
+
+    Example::
+
+        iot.TopicRule(self, "TopicRule",
+            sql=iot.IotSql.from_string_as_ver20160323("SELECT topic(2) as device_id, timestamp() as timestamp, temperature FROM 'device/+/data'"),
+            actions=[
+                actions.IotRepublishMqttAction("${topic()}/republish",
+                    quality_of_service=actions.MqttQualityOfService.AT_LEAST_ONCE
+                )
+            ]
+        )
+    '''
+
+    def __init__(
+        self,
+        topic: builtins.str,
+        *,
+        quality_of_service: typing.Optional["MqttQualityOfService"] = None,
+        role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+    ) -> None:
+        '''
+        :param topic: The MQTT topic to which to republish the message.
+        :param quality_of_service: (experimental) The Quality of Service (QoS) level to use when republishing messages. Default: MqttQualityOfService.ZERO_OR_MORE_TIMES
+        :param role: (experimental) The IAM role that allows access to AWS service. Default: a new role will be created
+
+        :stability: experimental
+        '''
+        props = IotRepublishMqttActionProps(
+            quality_of_service=quality_of_service, role=role
+        )
+
+        jsii.create(self.__class__, self, [topic, props])
+
+    @jsii.member(jsii_name="bind")
+    def bind(self, rule: aws_cdk.aws_iot.ITopicRule) -> aws_cdk.aws_iot.ActionConfig:
+        '''(experimental) (experimental) Returns the topic rule action specification.
+
+        :param rule: -
+
+        :stability: experimental
+        '''
+        return typing.cast(aws_cdk.aws_iot.ActionConfig, jsii.invoke(self, "bind", [rule]))
+
+
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-iot-actions.IotRepublishMqttActionProps",
+    jsii_struct_bases=[CommonActionProps],
+    name_mapping={"role": "role", "quality_of_service": "qualityOfService"},
+)
+class IotRepublishMqttActionProps(CommonActionProps):
+    def __init__(
+        self,
+        *,
+        role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+        quality_of_service: typing.Optional["MqttQualityOfService"] = None,
+    ) -> None:
+        '''(experimental) Configuration properties of an action to republish MQTT messages.
+
+        :param role: (experimental) The IAM role that allows access to AWS service. Default: a new role will be created
+        :param quality_of_service: (experimental) The Quality of Service (QoS) level to use when republishing messages. Default: MqttQualityOfService.ZERO_OR_MORE_TIMES
+
+        :stability: experimental
+        :exampleMetadata: infused
+
+        Example::
+
+            iot.TopicRule(self, "TopicRule",
+                sql=iot.IotSql.from_string_as_ver20160323("SELECT topic(2) as device_id, timestamp() as timestamp, temperature FROM 'device/+/data'"),
+                actions=[
+                    actions.IotRepublishMqttAction("${topic()}/republish",
+                        quality_of_service=actions.MqttQualityOfService.AT_LEAST_ONCE
+                    )
+                ]
+            )
+        '''
+        self._values: typing.Dict[str, typing.Any] = {}
+        if role is not None:
+            self._values["role"] = role
+        if quality_of_service is not None:
+            self._values["quality_of_service"] = quality_of_service
+
+    @builtins.property
+    def role(self) -> typing.Optional[aws_cdk.aws_iam.IRole]:
+        '''(experimental) The IAM role that allows access to AWS service.
+
+        :default: a new role will be created
+
+        :stability: experimental
+        '''
+        result = self._values.get("role")
+        return typing.cast(typing.Optional[aws_cdk.aws_iam.IRole], result)
+
+    @builtins.property
+    def quality_of_service(self) -> typing.Optional["MqttQualityOfService"]:
+        '''(experimental) The Quality of Service (QoS) level to use when republishing messages.
+
+        :default: MqttQualityOfService.ZERO_OR_MORE_TIMES
+
+        :see: https://docs.aws.amazon.com/iot/latest/developerguide/mqtt.html#mqtt-qos
+        :stability: experimental
+        '''
+        result = self._values.get("quality_of_service")
+        return typing.cast(typing.Optional["MqttQualityOfService"], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "IotRepublishMqttActionProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.implements(aws_cdk.aws_iot.IAction)
 class KinesisPutRecordAction(
     metaclass=jsii.JSIIMeta,
@@ -910,6 +1052,44 @@ class LambdaFunctionAction(
         return typing.cast(aws_cdk.aws_iot.ActionConfig, jsii.invoke(self, "bind", [topic_rule]))
 
 
+@jsii.enum(jsii_type="@aws-cdk/aws-iot-actions.MqttQualityOfService")
+class MqttQualityOfService(enum.Enum):
+    '''(experimental) MQTT Quality of Service (QoS) indicates the level of assurance for delivery of an MQTT Message.
+
+    :see: https://docs.aws.amazon.com/iot/latest/developerguide/mqtt.html#mqtt-qos
+    :stability: experimental
+    :exampleMetadata: infused
+
+    Example::
+
+        iot.TopicRule(self, "TopicRule",
+            sql=iot.IotSql.from_string_as_ver20160323("SELECT topic(2) as device_id, timestamp() as timestamp, temperature FROM 'device/+/data'"),
+            actions=[
+                actions.IotRepublishMqttAction("${topic()}/republish",
+                    quality_of_service=actions.MqttQualityOfService.AT_LEAST_ONCE
+                )
+            ]
+        )
+    '''
+
+    ZERO_OR_MORE_TIMES = "ZERO_OR_MORE_TIMES"
+    '''(experimental) QoS level 0.
+
+    Sent zero or more times.
+    This level should be used for messages that are sent over reliable communication links or that can be missed without a problem.
+
+    :stability: experimental
+    '''
+    AT_LEAST_ONCE = "AT_LEAST_ONCE"
+    '''(experimental) QoS level 1.
+
+    Sent at least one time, and then repeatedly until a PUBACK response is received.
+    The message is not considered complete until the sender receives a PUBACK response to indicate successful delivery.
+
+    :stability: experimental
+    '''
+
+
 @jsii.implements(aws_cdk.aws_iot.IAction)
 class S3PutObjectAction(
     metaclass=jsii.JSIIMeta,
@@ -1511,9 +1691,12 @@ __all__ = [
     "FirehosePutRecordAction",
     "FirehosePutRecordActionProps",
     "FirehoseRecordSeparator",
+    "IotRepublishMqttAction",
+    "IotRepublishMqttActionProps",
     "KinesisPutRecordAction",
     "KinesisPutRecordActionProps",
     "LambdaFunctionAction",
+    "MqttQualityOfService",
     "S3PutObjectAction",
     "S3PutObjectActionProps",
     "SqsQueueAction",
